pub struct ReadOptions {
pub skip_layer_image_data: Option<bool>,
pub skip_composite_image_data: Option<bool>,
pub skip_thumbnail: Option<bool>,
pub skip_linked_files_data: Option<bool>,
pub throw_for_missing_features: Option<bool>,
pub log_missing_features: Option<bool>,
pub use_image_data: Option<bool>,
pub use_raw_data: Option<bool>,
pub use_raw_thumbnail: Option<bool>,
pub log_dev_features: Option<bool>,
pub strict: Option<bool>,
pub debug: Option<bool>,
}Expand description
TS ReadOptions.
The development-only log?: (...args) => void callback is not modeled here
(it is behaviour, not data); other dev flags are kept.
Fields
skip_layer_image_data: Option<bool>Does not load layer image data.
skip_composite_image_data: Option<bool>Does not load composite image data.
skip_thumbnail: Option<bool>Does not load thumbnail.
skip_linked_files_data: Option<bool>Does not load linked files (used in smart-objects).
throw_for_missing_features: Option<bool>Throws exception if features are missing.
log_missing_features: Option<bool>Logs if features are missing.
use_image_data: Option<bool>Keep image data as byte array instead of canvas.
use_raw_data: Option<bool>use_raw_thumbnail: Option<bool>Loads thumbnail raw data instead of decoding into canvas.
log_dev_features: Option<bool>Used only for development.
strict: Option<bool>Used only for development.
debug: Option<bool>Used only for development.