pub struct WriteOptions {
pub generate_thumbnail: Option<bool>,
pub trim_image_data: Option<bool>,
pub invalidate_text_layers: Option<bool>,
pub log_missing_features: Option<bool>,
pub no_background: Option<bool>,
pub psb: Option<bool>,
pub compress: Option<bool>,
}Expand description
TS WriteOptions.
Fields
generate_thumbnail: Option<bool>Automatically generates thumbnail from composite image.
trim_image_data: Option<bool>Trims transparent pixels from layer image data.
invalidate_text_layers: Option<bool>Invalidates text layer data, forcing Photoshop to redraw on load.
log_missing_features: Option<bool>Logs if features are missing.
no_background: Option<bool>Forces bottom layer to be treated as layer and not background.
psb: Option<bool>Saves document as PSB (Large Document Format) file.
compress: Option<bool>Uses zip compression when writing PSD file.